﻿using System.Collections.Generic;

namespace Eliza
{
    /// <summary>
    /// The I pattern.
    /// </summary>
    /// <seealso cref="Eliza.ComplexPattern" />
    class IPattern : ComplexPattern
    {
        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="IPattern"/> class.
        /// </summary>
        public IPattern()
        {
            // Create the decomp/reassembly rules
            List<DecompReassemblyRule> rules = new List<DecompReassemblyRule>();

            // Rule # 1 (same as AmPattern rule # 2)
            List<string> reassembledResponses = new List<string>();
            reassembledResponses.Add("IS IT BECAUSE YOU ARE (3) THAT YOU CAME TO ME?");
            reassembledResponses.Add("HOW LONG HAVE YOU BEEN (3)?");
            reassembledResponses.Add("DO YOU BELIEVE IT'S NORMAL TO BE (3)?");
            reassembledResponses.Add("DO YOU ENJOY BEING (3)?");

            // Not in Eliza, but added because they sound realistic
            reassembledResponses.Add("DO YOU KNOW ANYONE ELSE WHO IS (3)?");
            reassembledResponses.Add("HOW WOULD YOU FEEL IF YOU WEREN'T (3)?");
            reassembledResponses.Add("OH, YOU'RE (3)?");
            reassembledResponses.Add("ARE YOU GLAD YOU'RE (3)?");
            reassembledResponses.Add("WOULD YOU PREFER IT IF YOU WEREN'T (3)?");
            reassembledResponses.Add("REALLY?  YOU'RE (3)?");
            reassembledResponses.Add("I SEE.  SO YOU'RE (3).");

            DecompReassemblyRule rule = new DecompReassemblyRule("* I AM *", reassembledResponses);
            rules.Add(rule);

            // Rule # 2
            reassembledResponses = new List<string>();
            reassembledResponses.Add("DON'T YOU REALLY (3)?");
            reassembledResponses.Add("WHY DON'T YOU (3)?");
            reassembledResponses.Add("DO YOU WISH TO BE ABLE TO (3)?");
            reassembledResponses.Add("DOES THAT TROUBLE YOU?");

            // Not in Eliza, but added because they sound realistic
            reassembledResponses.Add("DO YOU KNOW ANYONE ELSE WHO DOESN'T (3)?");
            reassembledResponses.Add("HOW WOULD YOU FEEL IF YOU DID (3)?");
            reassembledResponses.Add("YOU REALLY DON'T (3)?");

            rule = new DecompReassemblyRule("* I DON'T *", reassembledResponses);
            rules.Add(rule);

            // Rule # 3
            reassembledResponses = new List<string>();
            reassembledResponses.Add("TELL ME MORE ABOUT SUCH FEELINGS.");
            reassembledResponses.Add("DO YOU OFTEN FEEL (3)?");
            reassembledResponses.Add("DO YOU ENJOY FEELING (3)?");
            reassembledResponses.Add("WHAT DOES FEELING (3) REMIND YOU OF?");

            // Not in Eliza, but added because they sound realistic
            reassembledResponses.Add("WHAT IF YOU DIDN'T FEEL (3)?");
            reassembledResponses.Add("HOW LONG HAVE YOU FELT (3)?");
            reassembledResponses.Add("DO YOU THINK YOUR FRIENDS ALSO FEEL (3)?");
            reassembledResponses.Add("WOULD YOU LIKE TO NOT FEEL (3)?");

            rule = new DecompReassemblyRule("* DO I FEEL *", reassembledResponses);
            rules.Add(rule);

            // Rule # 4
            reassembledResponses = new List<string>();
            reassembledResponses.Add("PERHAPS IN YOUR FANTASIES WE (3) EACH OTHER.");
            reassembledResponses.Add("DO YOU WISH TO (3) ME?");
            reassembledResponses.Add("YOU SEEM TO NEED TO (3) ME.");
            reassembledResponses.Add("DO YOU (3) ANYONE ELSE?");

            // Not in Eliza, but added because they sound realistic
            reassembledResponses.Add("REALLY?  YOU (3) ME?");
            reassembledResponses.Add("OH, YOU (3) ME?");

            rule = new DecompReassemblyRule("* I * YOU *", reassembledResponses);
            rules.Add(rule);

            // Rule # 5
            reassembledResponses = new List<string>();
            reassembledResponses.Add("I SEE.  (1).");   // More realistic than "YOU SAY (1)?"
            reassembledResponses.Add("CAN YOU ELABORATE ON THAT?");
            reassembledResponses.Add("DO YOU SAY (1) FOR SOME SPECIAL REASON?");
            reassembledResponses.Add("IT'S INTERESTING THAT (1).");

            // Not in Eliza, but added because they sound realistic
            reassembledResponses.Add("WHY DO YOU SAY (1)?");
            reassembledResponses.Add("OH, (1)?");
            reassembledResponses.Add("SO (1).");

            rule = new DecompReassemblyRule("*", reassembledResponses);
            rules.Add(rule);

            // Initialize the pattern
            this.Initialize(0, "I", rules);
        }

        #endregion
    }
}






